Future Plans
************

1.0.0
=====
* sign files
* unsign signed files
* Display signed files
* Display unsigned files
* Every above function can be recursive
* limit to .py files only
* Allow #!
* addition of \n in signatures
* initial docs

1.1.0
=====
* basic configuration(py files only)

1.2.0
=====
* basic configuration(for any file)
